import os
import sys

from colorconsole import terminal
from . utils import clear


def jt64_main_help():
    """Prints Main Help Message"""
    clear()
    screen = terminal.get_terminal(conEmu=False)
    print("------------------------------------------------------------")
    screen.set_color(3, 0)
    print(f"JTSDK64 Tools {os.environ['VERSION']} Help Menu")
    screen.reset_colors()
    print("------------------------------------------------------------")
    print("")
    print("The following commands are available throughout the JTSDK64")
    print("Tools Environment.")
    print("\nScripts Commands\n")
    print('{0:15}  {1}'.format("  jt64help", "Print This Help Menu"))
    print('{0:15}  {1}'.format("  jt64env", "Lists All Environment Variables"))
    print('{0:15}  {1}'.format("  jt64gentc", "Generate Tool Chain Files"))
    print('{0:15}  {1}'.format("  jt64version", "Checks Tool-Chain Versions"))
    print("\nShortcut Commands\n")
    print('{0:15}  {1}'.format("  home", "Return back to home directory"))
    print('{0:15}  {1}'.format("  msys2", "Launch MSYS2 Console"))




import os
from colorconsole import terminal

from jt64common import __qt_version_dict__

from colorconsole import terminal
from subprocess import PIPE
from subprocess import run


def clear():
    """Clear Screen Function"""
    os.system('cls' if os.name == 'nt' else 'clear')


def pause():
    """Simple pause command"""
    os.system("pause")


def cmd(command):
    """Default Subprocess Command
    Input
        str("command as string")
    Returns
        Output from shell command
    """
    result = run(command, stdout=PIPE, stderr=PIPE, universal_newlines=True, shell=True)
    return result.stdout




import os
import sys
import glob

from colorconsole import terminal
from . utils import clear


def main_header_message():
    """JTSDK64 Main Menu Headder Message"""
    screen = terminal.get_terminal(conEmu=False)
    clear()
    print("--------------------------------------------------")
    screen.set_color(3, 0)
    print(f"JTSDK64 Tools {os.environ['VERSION']}")
    screen.reset_colors()
    print("--------------------------------------------------")
    print('{0:18}  {1}'.format("\nQT Version", os.environ["QTV"]))
    print('{0:17}  {1}'.format("Core Tools", os.environ["CORETOOLS"]))
    print('{0:17}  {1}'.format("Python", os.environ["PYTOOLS"]))
    print('{0:17}  {1}'.format("Postgres", os.environ["POSTGRES"]))
    print('{0:17}  {1}'.format("Unix Tools", os.environ["UNIXTOOLS"]))
    screen.cprint(14, 0, "\nFor Command List, Type: jt64help\n")
    screen.reset_colors()

